
<!---
FrozenIsBool True
-->

##Example

Let's command. First the Commander module uses the GetList and the SetList that always transform a value into a VariablesList that can be respectively map@get and map@set.